@@ -52,6 +52,13 @@ class HttpTarget(proto.Message):
     request, the response returned by the redirected request is
     considered.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         uri (str):
             Required. The full URI path that the request will be sent
@@ -99,6 +106,8 @@ class HttpTarget(proto.Message):
 
             This type of authorization should generally only be used
             when calling Google APIs hosted on \*.googleapis.com.
+
+            This field is a member of `oneof`_ ``authorization_header``.
         oidc_token (google.cloud.scheduler_v1beta1.types.OidcToken):
             If specified, an
             `OIDC <https://developers.google.com/identity/protocols/OpenIDConnect>`__
@@ -108,6 +117,8 @@ class HttpTarget(proto.Message):
             This type of authorization can be used for many scenarios,
             including calling Cloud Run, or endpoints where you intend
             to validate the token yourself.
+
+            This field is a member of `oneof`_ ``authorization_header``.
     """
 
     uri = proto.Field(proto.STRING, number=1,)
